@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class ImportWizardDisplayInfo : public LibImportWizard::AbstractDisplayInfo
 {
 public:
     explicit ImportWizardDisplayInfo(ImportWizard *wizard);
-    ~ImportWizardDisplayInfo();
+    ~ImportWizardDisplayInfo() override;
 
     void calendarImportError(const QString &log) override;
     void settingsImportError(const QString &log) override;
